# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`tlog`](#tlog): This module manages the configuration of [TLog](https://github.com/Scribery/tlog)
* [`tlog::config::rsyslog`](#tlog--config--rsyslog): Manage local syslog hooks for tlog
* [`tlog::rec_session`](#tlog--rec_session): Configure `tlog-rec-session`  This is pulled out from the main `tlog` class because of the rapidly moving nature of the project. Having this 

#### Private Classes

* `tlog::install`: This class is called from tlog for install.

### Data types

* [`Tlog::RecSessionConf`](#Tlog--RecSessionConf): Configuration options for the tlog-rec-session.conf

## Classes

### <a name="tlog"></a>`tlog`

This module manages the configuration of [TLog](https://github.com/Scribery/tlog)

#### Parameters

The following parameters are available in the `tlog` class:

* [`package_name`](#-tlog--package_name)
* [`package_ensure`](#-tlog--package_ensure)
* [`manage_rsyslog`](#-tlog--manage_rsyslog)

##### <a name="-tlog--package_name"></a>`package_name`

Data type: `String[1]`

The name of the tlog package

Default value: `'tlog'`

##### <a name="-tlog--package_ensure"></a>`package_ensure`

Data type: `String[1]`

What should be passed to the `ensure` parameter for all package resources

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-tlog--manage_rsyslog"></a>`manage_rsyslog`

Data type: `Boolean`

If true, manage logging configuration for tlog

Default value: `simplib::lookup('simp_options::syslog', { 'default_value' => false })`

### <a name="tlog--config--rsyslog"></a>`tlog::config::rsyslog`

Manage local syslog hooks for tlog

#### Parameters

The following parameters are available in the `tlog::config::rsyslog` class:

* [`logrotate_options`](#-tlog--config--rsyslog--logrotate_options)
* [`match_rule`](#-tlog--config--rsyslog--match_rule)
* [`log_file`](#-tlog--config--rsyslog--log_file)
* [`logrotate_create`](#-tlog--config--rsyslog--logrotate_create)
* [`stop_processing`](#-tlog--config--rsyslog--stop_processing)
* [`logrotate`](#-tlog--config--rsyslog--logrotate)

##### <a name="-tlog--config--rsyslog--logrotate_options"></a>`logrotate_options`

Data type: `Hash`

Options to pass to the `logrotate::rule` defined type

* Will be deep merged through Hiera by default
* The `log_files` option will not be honored if passed

@see `data/common.yaml`

##### <a name="-tlog--config--rsyslog--match_rule"></a>`match_rule`

Data type: `String[1]`

The rule that should be used for matching TLOG rules

* The default is set to match rules on the widest selection of systems
  possible.

Default value: `'$programname == \'tlog-rec-session\' or $programname == \'-tlog-rec-session\' or $programname == \'tlog\''`

##### <a name="-tlog--config--rsyslog--log_file"></a>`log_file`

Data type: `Stdlib::Absolutepath`

The log file in which to save the `tlog` logs

Default value: `'/var/log/tlog.log'`

##### <a name="-tlog--config--rsyslog--logrotate_create"></a>`logrotate_create`

Data type: `Pattern['\d{4} .+ .+']`

The create options to specify in the logrotate rule

Default value: `'0640 tlog tlog'`

##### <a name="-tlog--config--rsyslog--stop_processing"></a>`stop_processing`

Data type: `Boolean`

Cease processing syslog rules after processing this rule

Default value: `true`

##### <a name="-tlog--config--rsyslog--logrotate"></a>`logrotate`

Data type: `Boolean`

Enable log rotation for `$log_file`

Default value: `simplib::lookup('simp_options::logrotate', { 'default_value' => false })`

### <a name="tlog--rec_session"></a>`tlog::rec_session`

Configure `tlog-rec-session`

This is pulled out from the main `tlog` class because of the rapidly moving
nature of the project. Having this decoupled will allow us to refactor as
necessary as the software progresses.

#### Parameters

The following parameters are available in the `tlog::rec_session` class:

* [`options`](#-tlog--rec_session--options)
* [`custom_options`](#-tlog--rec_session--custom_options)
* [`shell_hook`](#-tlog--rec_session--shell_hook)
* [`shell_hook_users`](#-tlog--rec_session--shell_hook_users)
* [`shell_hook_users_file`](#-tlog--rec_session--shell_hook_users_file)
* [`shell_hook_cmd`](#-tlog--rec_session--shell_hook_cmd)

##### <a name="-tlog--rec_session--options"></a>`options`

Data type: `Tlog::RecSessionConf`

Configuration options for tlog-rec-session

* Will be deep merged through Hiera by default
* Unfortunately, the file is not "real" JSON and so Augeas lenses and/or
  Ruby won't work to do ad-hoc configuration until after the file is managed.
* This set covers the known options in known formats. Use `$custom_options`
  for arbitrary settings.
* Note: If the `writer` option is not set, a sane default for the target
  platform will be selected.

@see data/common.yaml
@see types/recsession.pp

##### <a name="-tlog--rec_session--custom_options"></a>`custom_options`

Data type: `Hash`

An **unvalidated** `Hash` of options that will be converted to JSON and
merged, with preference, into `$options`

Default value: `{}`

##### <a name="-tlog--rec_session--shell_hook"></a>`shell_hook`

Data type: `Boolean`

Add hooks into /etc/profile.d that will automatically record sessions for
interactive and/or login shells

Default value: `true`

##### <a name="-tlog--rec_session--shell_hook_users"></a>`shell_hook_users`

Data type: `Array[String[1]]`

The list of users that you want to automatically record that will be stored
in `$shell_hook_users_file`

Default value: `[ 'root' ]`

##### <a name="-tlog--rec_session--shell_hook_users_file"></a>`shell_hook_users_file`

Data type: `Stdlib::Absolutepath`

The path to the file containing the list of users and/or groups that you
want to automatically record

* Users should be specified as `Strings`
* Groups should be prefaces with a `%`

Default value: `'/etc/security/tlog.users'`

##### <a name="-tlog--rec_session--shell_hook_cmd"></a>`shell_hook_cmd`

Data type: `Stdlib::Absolutepath`

The path to `tlog-rec-session`

Default value: `'/usr/bin/tlog-rec-session'`

## Data types

### <a name="Tlog--RecSessionConf"></a>`Tlog::RecSessionConf`

Configuration options for the tlog-rec-session.conf

Alias of

```puppet
Struct[{
  Optional['shell']    => Stdlib::Absolutepath,
  Optional['notice']   => String,
  Optional['writer']   => Enum['journal', 'syslog', 'file'],
  Optional['latency']  => Integer[1],
  Optional['payload']  => Integer[1],
  Optional['log'] => Struct[{
    Optional['input']  => Boolean,
    Optional['output'] => Boolean,
    Optional['window'] => Boolean
  }],
  Optional['limit'] => Struct[{
    Optional['rate']   => Integer[1],
    Optional['burst']  => Integer[1],
    Optional['action'] => Enum['pass','delay','drop']
  }],
  Optional['file'] => Struct[{
    'path' => Stdlib::Absolutepath
  }],
  Optional['syslog'] => Struct[{
    Optional['facility'] => Simplib::Syslog::LowerFacility,
    Optional['priority'] => Simplib::Syslog::LowerSeverity
  }],
  Optional['journal'] => Struct[{
    Optional['priority'] => Simplib::Syslog::LowerSeverity,
    Optional['augment']  => Boolean
  }]
}]
```

